@@ -20,4 +20,8 @@ def reset_whitelist(discord_id: int):
 
 def whitelist(discord_id: int):
     response = requests.get(api_url + f"premium?discord_id={discord_id}&api_key={apikey}")
-    return response.json()
\ No newline at end of file
+    return response.json()
+
+def get_whitelist_list():
+    response = requests.get(api_url + f"premium_list?api_key={apikey}")
+    return response.json()
